==> object-oriented-bootstrap-modal-0.0.7.tgz: package/bundle.js <==
class ElementContainer {
    constructor(shadowHost, shadowRoot) {
        this.shadowHost = shadowHost;
        this.shadowRoot = shadowRoot;
        this.isOpen = false;
    }
    insertSelf() {
        if (!this.isOpen) {
            document.body.appendChild(this.shadowHost);
            this.isOpen = true;
        }
    }
    removeSelf() {
        if (this.isOpen) {
            document.body.removeChild(this.shadowHost);
            this.isOpen = false;
        }
    }
    getContentElement() {
        return this.shadowRoot.querySelector('.modal-body');
    }
    addCloseButtonListener(onClose) {
        // Remember there are 2 close buttons
        this.shadowRoot.querySelectorAll('*[closeButton]')
            .forEach(item => item.addEventListener('click', onClose));
    }
    addConfirmButtonListener(onConfirm) {
        this.shadowRoot.querySelector('.btn.btn-primary[confirmButton]')
            .addEventListener('click', onConfirm);
    }
}

const templateHTML = `

<link 
    href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" 
    rel="stylesheet" 
    integrity="sha384-1BmE4kWBq78iYhFldvKuhfTAU6auU8tT94WrHftjDbrCEXSU1oBoqyl2QvZ6jIW3" 
    crossorigin="anonymous" 
/>

<style>
* {
    font-family: system-ui,-apple-system,"Segoe UI",Roboto,"Helvetica Neue",Arial,"Noto Sans","Liberation Sans",sans-serif,"Apple Color Emoji","Segoe UI Emoji","Segoe UI Symbol","Noto Color Emoji";
}
</style>

<div class="modal fade show" tabindex="-1" style="display: block; background-color: RGBA(0, 0, 0, 0.5);">
    <div class="modal-dialog modal-xl">
        <div class="modal-content">
        
            <div class="modal-header">
                <h5 class="modal-title">$TITLE</h5>
                <button type="button" class="btn-close" closeButton></button>
            </div>
            
            <div class="modal-body">
                $CONTENT
            </div>
            
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" closeButton>Close</button>
                <button type="button" class="btn btn-primary" confirmButton>Confirm</button>
            </div>
            
        </div>
    </div>
</div>

`;

class ElementContainerFactory {
    constructor(config) {
        this.config = config;
    }
    createContainer() {
        const root = document.createElement('div');
        ElementContainerFactory.setRootStyles(root);
        const shadowRoot = root.attachShadow({ mode: "closed" });
        this.mountTemplate(shadowRoot);
        const container = new ElementContainer(root, shadowRoot);
        if (this.config.content instanceof HTMLElement) {
            container.getContentElement().appendChild(this.config.content);
        }
        return container;
    }
    static setRootStyles(root) {
        root.style.all = 'initial';
    }
    mountTemplate(shadowRoot) {
        let html = templateHTML.replace('$TITLE', this.config.header);
        if (typeof this.config.content === 'string') {
            html = html.replace('$CONTENT', this.config.content);
        }
        else {
            html = html.replace('$CONTENT', '');
        }
        shadowRoot.innerHTML = html;
    }
}

/**
 * This class listens to the escape key and closes this.host if esc is pressed.
 */
class EscListener {
    constructor(host) {
        this.host = host;
        this.onKeyPress = (e) => {
            if (e.key === 'Escape') {
                this.host.close();
            }
        };
    }
    engage() {
        document.addEventListener('keyup', this.onKeyPress);
    }
    disengage() {
        document.removeEventListener('keyup', this.onKeyPress);
    }
}

/**
 * This class specialises in listening to ctrl+enter events
 */
class CtrlEnterListener {
    constructor(callback) {
        this.callback = callback;
        this.rawListener = (e) => {
            if ((e.ctrlKey || e.metaKey) && e.key === 'Enter') {
                this.callback();
            }
        };
    }
    engage() {
        document.addEventListener('keypress', this.rawListener);
    }
    disengage() {
        document.removeEventListener('keypress', this.rawListener);
    }
}

class ObjectOrientedBootstrapModal {
    constructor(config) {
        this.escListener = new EscListener(this);
        this.onConfirm = null;
        this.rawOnConfirmListener = () => {
            if (this.onConfirm) {
                this.onConfirm();
            }
        };
        this.container = new ElementContainerFactory(config).createContainer();
        if (config.onConfirm) {
            this.onConfirm = config.onConfirm;
        }
        this.container.addConfirmButtonListener(this.rawOnConfirmListener);
        this.ctrlEnterListener = new CtrlEnterListener(this.rawOnConfirmListener);
        this.container.addCloseButtonListener(this.close.bind(this));
    }
    open() {
        this.container.insertSelf();
        this.escListener.engage();
        this.ctrlEnterListener.engage();
    }
    close() {
        this.container.removeSelf();
        this.escListener.disengage();
        this.ctrlEnterListener.disengage();
    }
    get content() {
        return this.container.getContentElement();
    }
}

export { ObjectOrientedBootstrapModal };

==> object-oriented-bootstrap-modal-0.0.8.tgz: package/bundle.js <==
class ElementContainer {
    constructor(shadowHost, shadowRoot) {
        this.shadowHost = shadowHost;
        this.shadowRoot = shadowRoot;
        this.isOpen = false;
    }
    insertSelf() {
        if (!this.isOpen) {
            document.body.appendChild(this.shadowHost);
            this.isOpen = true;
        }
    }
    removeSelf() {
        if (this.isOpen) {
            document.body.removeChild(this.shadowHost);
            this.isOpen = false;
        }
    }
    getContentElement() {
        return this.shadowRoot.querySelector('.modal-body');
    }
    addCloseButtonListener(onClose) {
        // Remember there are 2 close buttons
        this.shadowRoot.querySelectorAll('*[closeButton]')
            .forEach(item => item.addEventListener('click', onClose));
    }
    addConfirmButtonListener(onConfirm) {
        this.shadowRoot.querySelector('.btn.btn-primary[confirmButton]')
            .addEventListener('click', onConfirm);
    }
}

const templateHTML = `

<link 
    href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css" 
    rel="stylesheet" 
    integrity="sha384-1BmE4kWBq78iYhFldvKuhfTAU6auU8tT94WrHftjDbrCEXSU1oBoqyl2QvZ6jIW3" 
    crossorigin="anonymous" 
/>

<style>
* {
    --bs-blue: #0d6efd;
    --bs-indigo: #6610f2;
    --bs-purple: #6f42c1;
    --bs-pink: #d63384;
    --bs-red: #dc3545;
    --bs-orange: #fd7e14;
    --bs-yellow: #ffc107;
    --bs-green: #198754;
    --bs-teal: #20c997;
    --bs-cyan: #0dcaf0;
    --bs-white: #fff;
    --bs-gray: #6c757d;
    --bs-gray-dark: #343a40;
    --bs-gray-100: #f8f9fa;
    --bs-gray-200: #e9ecef;
    --bs-gray-300: #dee2e6;
    --bs-gray-400: #ced4da;
    --bs-gray-500: #adb5bd;
    --bs-gray-600: #6c757d;
    --bs-gray-700: #495057;
    --bs-gray-800: #343a40;
    --bs-gray-900: #212529;
    --bs-primary: #0d6efd;
    --bs-secondary: #6c757d;
    --bs-success: #198754;
    --bs-info: #0dcaf0;
    --bs-warning: #ffc107;
    --bs-danger: #dc3545;
    --bs-light: #f8f9fa;
    --bs-dark: #212529;
    --bs-primary-rgb: 13,110,253;
    --bs-secondary-rgb: 108,117,125;
    --bs-success-rgb: 25,135,84;
    --bs-info-rgb: 13,202,240;
    --bs-warning-rgb: 255,193,7;
    --bs-danger-rgb: 220,53,69;
    --bs-light-rgb: 248,249,250;
    --bs-dark-rgb: 33,37,41;
    --bs-white-rgb: 255,255,255;
    --bs-black-rgb: 0,0,0;
    --bs-body-color-rgb: 33,37,41;
    --bs-body-bg-rgb: 255,255,255;
    --bs-font-sans-serif: system-ui,-apple-system,"Segoe UI",Roboto,"Helvetica Neue",Arial,"Noto Sans","Liberation Sans",sans-serif,"Apple Color Emoji","Segoe UI Emoji","Segoe UI Symbol","Noto Color Emoji";
    --bs-font-monospace: SFMono-Regular,Menlo,Monaco,Consolas,"Liberation Mono","Courier New",monospace;
    --bs-gradient: linear-gradient(180deg, rgba(255, 255, 255, 0.15), rgba(255, 255, 255, 0));
    --bs-body-font-family: var(--bs-font-sans-serif);
    --bs-body-font-size: 1rem;
    --bs-body-font-weight: 400;
    --bs-body-line-height: 1.5;
    --bs-body-color: #212529;
    --bs-body-bg: #fff;
    margin: 0;
    font-family: var(--bs-body-font-family);
    font-size: var(--bs-body-font-size);
    font-weight: var(--bs-body-font-weight);
    line-height: var(--bs-body-line-height);
    color: var(--bs-body-color);
    text-align: var(--bs-body-text-align);
    background-color: var(--bs-body-bg);
    -webkit-text-size-adjust: 100%;
    -webkit-tap-highlight-color: transparent;
}
</style>

<div class="modal fade show" tabindex="-1" style="display: block; background-color: RGBA(0, 0, 0, 0.5);">
    <div class="modal-dialog modal-xl">
        <div class="modal-content">
        
            <div class="modal-header">
                <h5 class="modal-title">$TITLE</h5>
                <button type="button" class="btn-close" closeButton></button>
            </div>
            
            <div class="modal-body">
                $CONTENT
            </div>
            
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" closeButton>Close</button>
                <button type="button" class="btn btn-primary" confirmButton>Confirm</button>
            </div>
            
        </div>
    </div>
</div>

`;

class ElementContainerFactory {
    constructor(config) {
        this.config = config;
    }
    createContainer() {
        const root = document.createElement('div');
        ElementContainerFactory.setRootStyles(root);
        const shadowRoot = root.attachShadow({ mode: "closed" });
        this.mountTemplate(shadowRoot);
        const container = new ElementContainer(root, shadowRoot);
        if (this.config.content instanceof HTMLElement) {
            container.getContentElement().appendChild(this.config.content);
        }
        return container;
    }
    static setRootStyles(root) {
        root.style.all = 'initial';
    }
    mountTemplate(shadowRoot) {
        let html = templateHTML.replace('$TITLE', this.config.header);
        if (typeof this.config.content === 'string') {
            html = html.replace('$CONTENT', this.config.content);
        }
        else {
            html = html.replace('$CONTENT', '');
        }
        shadowRoot.innerHTML = html;
    }
}

/**
 * This class listens to the escape key and closes this.host if esc is pressed.
 */
class EscListener {
    constructor(host) {
        this.host = host;
        this.onKeyPress = (e) => {
            if (e.key === 'Escape') {
                this.host.close();
            }
        };
    }
    engage() {
        document.addEventListener('keyup', this.onKeyPress);
    }
    disengage() {
        document.removeEventListener('keyup', this.onKeyPress);
    }
}

/**
 * This class specialises in listening to ctrl+enter events
 */
class CtrlEnterListener {
    constructor(callback) {
        this.callback = callback;
        this.rawListener = (e) => {
            if ((e.ctrlKey || e.metaKey) && e.key === 'Enter') {
                this.callback();
            }
        };
    }
    engage() {
        document.addEventListener('keypress', this.rawListener);
    }
    disengage() {
        document.removeEventListener('keypress', this.rawListener);
    }
}

class ObjectOrientedBootstrapModal {
    constructor(config) {
        this.escListener = new EscListener(this);
        this.onConfirm = null;
        this.rawOnConfirmListener = () => {
            if (this.onConfirm) {
                this.onConfirm();
            }
        };
        this.container = new ElementContainerFactory(config).createContainer();
        if (config.onConfirm) {
            this.onConfirm = config.onConfirm;
        }
        this.container.addConfirmButtonListener(this.rawOnConfirmListener);
        this.ctrlEnterListener = new CtrlEnterListener(this.rawOnConfirmListener);
        this.container.addCloseButtonListener(this.close.bind(this));
    }
    open() {
        this.container.insertSelf();
        this.escListener.engage();
        this.ctrlEnterListener.engage();
    }
    close() {
        this.container.removeSelf();
        this.escListener.disengage();
        this.ctrlEnterListener.disengage();
    }
    get content() {
        return this.container.getContentElement();
    }
}

export { ObjectOrientedBootstrapModal };
